.. _libdoc_tensor_random:

=============================================
:mod:`random` -- Low-level random numbers
=============================================

Low-level random numbers
------------------------

The :mod:`aesara.tensor.random` module provides random-number drawing functionality
that closely resembles the :mod:`numpy.random` module.

.. toctree::
    :maxdepth: 2

    basic
    utils


.. automodule:: aesara.tensor.random.basic
    :members:
